@@ -30,7 +30,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS); # Exporter vars
 use vars qw($NAME $ABSTRACT $VERSION);
 $NAME     = 'Starfish';
 $ABSTRACT = 'Perl-based System for Text-Embedded Programming and Preprocessing';
-$VERSION  = '1.26';
+$VERSION  = '1.27';
 
 use vars qw($Revision);
 ($Revision = substr(q$Revision: $, 10)) =~ s/\s+$//;
@@ -274,9 +274,11 @@ sub digest {
     goto START;
   }
 
-  # Final routine, if defined
-  if (defined($self->{Final}) && ref($self->{Final}) eq 'CODE') {
-    $self->{Out} = &{$self->{Final}}($self->{Out});
+  # Final routines, if defined
+  if (defined($self->{Final})) {
+    my @a = @{ $self->{Final} };
+    for my $f (@a) {
+      $self->{Out} = &{$f}($self->{Out}); }
   }
   
   # Related to the macro concept (e.g. code folding)
@@ -971,6 +973,13 @@ sub rmAllHooks {
 
 sub resetHooks { my $self = shift; $self->rmAllHooks(); $self->setStyle(); }
 
+sub add_final {
+  my $self = shift;
+  my $f = shift; die "$f not a function" unless ref($f) eq 'CODE';
+  if (!defined($self->{Final})) { $self->{Final} = [] }
+  push @{ $self->{Final} }, $f;
+}
+
 sub defineMacros {
     my $self = shift;
 
@@ -1392,12 +1401,12 @@ Generating text with a variable replacement:
   %  sfish_add_tag('sl,l', 'echo');
   %  sfish_add_tag('slide', 'echo');
   %  sfish_ignore_outer;
-  %  $Star->{Final} = sub {
+  %  $Star->add_final( sub {
   %    my $r = shift;
   %    $r =~ s/^% -\*- compile-command.*\n//;
   %    $r.= "\\end{document}\n";
   %    return $r;
-  %  }
+  %  } );
   % !>
 
   \section{Course Introduction}
@@ -1546,10 +1555,11 @@ questionable decision.
 
 =head2 $Star->{Final}
 
-If defined as a CODE reference to a function (sub), it is executed on
-the final output before writing it out.  It is used as the final routine,
-typically to add or remove some of the first lines or final lines.
-The function takes input as a parameter and returns it after processing.
+If defined, it should be an array of CODE references, which are applied as
+functions on the final output before writing it out.  These are used as final
+routines, typically to add or remove some of the first lines or finals lines.
+Each functionj takes input as a parameter and returns it after processing.
+The variable should accessed using the method C<add_final>.
 
 =head2 $Star->{INFILE}
 
